rpms/wireless-tools/FC-2 wireless-tools-27-atheros-abg-fix.patch, NONE, 1.1 wireless-tools-27-loosen-version-check.patch, NONE, 1.1 wireless-tools-28-makefile.patch, NONE, 1.1

fedora-cvs-commits at redhat.com fedora-cvs-commits at redhat.com
Fri Apr 1 15:38:16 UTC 2005


Update of /cvs/dist/rpms/wireless-tools/FC-2
In directory cvs.devel.redhat.com:/tmp/cvs-serv6359

Added Files:
	wireless-tools-27-atheros-abg-fix.patch 
	wireless-tools-27-loosen-version-check.patch 
	wireless-tools-28-makefile.patch 
Log Message:
Add some missing patches


wireless-tools-27-atheros-abg-fix.patch:
 iwlib.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

--- NEW FILE wireless-tools-27-atheros-abg-fix.patch ---
--- wireless_tools.27/iwlib.c.version-check	2005-04-01 10:08:22.051216766 -0500
+++ wireless_tools.27/iwlib.c	2005-04-01 10:09:43.563904214 -0500
@@ -516,7 +516,7 @@
 
       /* We don't like future versions of WE, because we can't cope with
        * the unknown */
-      if(range->we_version_compiled > WE_VERSION)
+      if(range->we_version_compiled > WE_VERSION + 1)
 	{
 	  fprintf(stderr, "Warning: Driver for device %s has been compiled with version %d\n", ifname, range->we_version_compiled);
 	  fprintf(stderr, "of Wireless Extension, while this program supports up to version %d.\n", WE_VERSION);

wireless-tools-28-makefile.patch:
 Makefile |    6 +++++-
 1 files changed, 5 insertions(+), 1 deletion(-)

--- NEW FILE wireless-tools-28-makefile.patch ---
--- wireless_tools.28/Makefile.makefile	2005-01-13 18:41:21.000000000 -0500
+++ wireless_tools.28/Makefile	2005-01-17 15:50:46.143069822 -0500
@@ -91,12 +91,15 @@
   STRIPFLAGS=
 endif
 
+ifndef OPT_FLAGS
+  OPT_FLAGS=
+endif
 # Other flags
 CFLAGS=-Os -W -Wall -Wstrict-prototypes -Wmissing-prototypes -Wshadow \
 	-Wpointer-arith -Wcast-qual -Winline -I.
 #CFLAGS=-O2 -W -Wall -Wstrict-prototypes -I.
 DEPFLAGS=-MMD
-XCFLAGS=$(CFLAGS) $(DEPFLAGS) $(WARN) $(HEADERS) $(WELIB_FLAG)
+XCFLAGS=$(CFLAGS) $(DEPFLAGS) $(WARN) $(HEADERS) $(WELIB_FLAG) $(OPT_FLAGS)
 PICFLAG=-fPIC
 
 # Standard compilation targets
@@ -136,6 +139,7 @@
 # Compilation of the dynamic library
 $(DYNAMIC): $(OBJS:.o=.so)
 	$(CC) -shared -o $@ -Wl,-soname,$@ $(STRIPFLAGS) $(LIBS) -lc $^
+	ln -s $@ $(DYNAMIC_LINK)
 
 # Compilation of the static library
 $(STATIC): $(OBJS)




More information about the fedora-cvs-commits mailing list
--- wireless_tools.27/iwlib.c.atheros-fix	2005-04-01 10:02:01.125668727 -0500
+++ wireless_tools.27/iwlib.c	2005-04-01 10:02:44.640113303 -0500
@@ -2459,9 +2459,9 @@
   int			buflen = IW_SCAN_MAX_DATA; /* Min for compat WE<17 */
   unsigned char *	newbuf;
 
   /* Don't waste too much time on interfaces (50 * 100 = 5s) */
   context->retry++;
-  if(context->retry > 50)
+  if(context->retry > 150)
     {
       errno = ETIME;
       return(-1);

wireless-tools-27-loosen-version-check.patch:
 iwlib.c |    2 +-
 1 files changed, 1 insertion(+), 1 deletion(-)

--- NEW FILE wireless-tools-27-loosen-version-check.patch ---
@@ -2459,9 +2459,9 @@
   unsigned char *	newbuf;
 
-  /* Don't waste too much time on interfaces (50 * 100 = 5s) */
+  /* Don't waste too much time on interfaces (150 * 100 = 15s) */
   context->retry++;